@@ -21,6 +21,12 @@ SCRIPT_PATH=`pwd`;
 popd  > /dev/null
 source $SCRIPT_PATH/env.sh
 
+
+read -p "Enter admin login: " LOGIN
+read -s -p "Enter admin password: " PASSWORD
+echo "" # new line
+read -p "Enter admin mail: " MAIL
+
 test_var_env "BIOMAJ_ROOT" "${BIOMAJ_ROOT}"
 
 
@@ -29,6 +35,6 @@ test_var_env "BIOMAJ_ROOT" "${BIOMAJ_ROOT}"
 #	true
 #else
 	echo 'Creating database...'
-	java -cp $BIOMAJ_ROOT/lib/biomaj.jar org.inria.biomaj.sql.CreateDB
+	java -cp $BIOMAJ_ROOT/lib/biomaj.jar org.inria.biomaj.sql.CreateDB $LOGIN $PASSWORD $MAIL
 	echo 'Done.'
 #fi
