@@ -22,6 +22,10 @@ source $SCRIPT_PATH/env.sh
 
 test_var_env "BIOMAJ_ROOT" "${BIOMAJ_ROOT}"
 
+if [ ! -d $BIOMAJ_ROOT/tmp ]; then
+	mkdir $BIOMAJ_ROOT/tmp
+fi
+
 if [ -f $BIOMAJ_ROOT/tmp/db.pid ]; then
 	PID=`head -1 $BIOMAJ_ROOT/tmp/db.pid`
 	if ! ps $PID | grep bmajdb > /dev/null
