@@ -116,9 +116,24 @@ public class DBWriter {
 		long updateId = -1;
 		
 		if (newSession) { // Create a new session element
-			if (bank.getListOldSession().size() == 0 || // If the session is ok and is not a removeprocess
-					(bank.getListOldSession().get(bank.getListOldSession().size() - 1).getStatus()
-							&& !(bank.getListOldSession().size() == 1 && bank.getListOldSession().get(0).getWorkflowTask(Session.REMOVEPROCESS) != null))) { // If the latest session is ok, create a new update element
+			GeneralWorkflowTask isDeployed = null;
+			int oldSessionListSize = bank.getListOldSession().size();
+			if(oldSessionListSize>0) {
+				/*
+				 *  We have some previous update sessions
+				 *  Did last session made a deployment ? If yes we can switch to a new update session
+				 *  else we should keep the same update session id
+				 */
+				
+				isDeployed = bank.getListOldSession().get(oldSessionListSize - 1).getWorkflowTask(Session.DEPLOYMENT);
+				
+			}
+			if (oldSessionListSize == 0 || // If the session is ok (deployed) and is not a removeprocess
+				(
+				  (bank.getListOldSession().get(oldSessionListSize - 1).getStatus() && isDeployed!=null)
+				&&
+				  !(oldSessionListSize == 1 && bank.getListOldSession().get(0).getWorkflowTask(Session.REMOVEPROCESS) != null))
+				) { // If the latest session is ok, create a new update element
 				/*
 				 * NEW UPDATE
 				 */
