@@ -130,7 +130,7 @@ public class TestBmajExtract {
 		file.delete();
 		String rnd = "alezkj lkj^ij mk	j ifj mkjqsmkj	m kjsqmdlkj qmskj " +
 				"szd kqjm kj mqskj mkfjmri mlzkrjzm lkj mlkj zoiapodjk kj zklj " +
-				"zevdmlkjb iJmZRIJMQKLJ ẐROBJÙMllmkj mkj mlkjdm lkjm";
+				"zevdmlkjb iJmZRIJMQKLJ eROBJoMllmkj mkj mlkjdm lkjm";
 		
 		PrintWriter pw;
 		try {
