@@ -70,6 +70,12 @@ public class TestBmajLink {
 		}
 		
 		link.execute();
+		
+		try {
+			TimeUnit.SECONDS.sleep(2); // Wait for files to be created
+		} catch (Exception e) {
+			e.printStackTrace();
+		}
 	}
 	
 	/**
@@ -116,7 +122,7 @@ public class TestBmajLink {
 		file.delete();
 		String rnd = "alezkj lkj-ij mk	j ifj mkjqsmkj	m kjsqmdlkj qmskj " +
 				"szd kqjm kj mqskj mkfjmri mlzkrjzm lkj mlkj zoiapodjk kj zklj " +
-				"zevdmlkjb iJmZRIJMQKLJ _ROBJÙMllmkj mkj mlkjdm lkjm";
+				"zevdmlkjb iJmZRIJMQKLJ eROBJoMllmkj mkj mlkjdm lkjm";
 		
 		PrintWriter pw;
 		try {
