@@ -113,7 +113,7 @@ public class TestBmajMove {
 		file.delete();
 		String rnd = "alezkj lkj-ij mk	j ifj mkjqsmkj	m kjsqmdlkj qmskj " +
 				"szd kqjm kj mqskj mkfjmri mlzkrjzm lkj mlkj zoiapodjk kj zklj " +
-				"zevdmlkjb iJmZRIJMQKLJ _ROBJÙMllmkj mkj mlkjdm lkjm";
+				"zevdmlkjb iJmZRIJMQKLJ eROBJoMllmkj mkj mlkjdm lkjm";
 		
 		PrintWriter pw;
 		try {
