@@ -62,6 +62,11 @@ import org.inria.biomaj.singleton.BiomajInformation;
 import org.inria.biomaj.utils.BiomajConst;
 import org.inria.biomaj.utils.BiomajException;
 
+/**
+ * 18/06/13 [#15914] ant 1.9 return objects in getProperties instead of String
+ * @author osallou
+ *
+ */
 
 public class BankFactory {
 
@@ -297,7 +302,7 @@ public class BankFactory {
 							
 //							File childBank = new File(BiomajInformation.getInstance().getProperty(BiomajInformation.WORKFLOWSDIR) + "/" + bankName + ".properties");
 							File childBank = getBankPath(bankName);
-							if (childBank.exists()) {
+							if (childBank!=null && childBank.exists()) {
 								FileReader reader = new FileReader(childBank);
 								childProps.load(reader);
 								reader.close();
@@ -384,7 +389,7 @@ public class BankFactory {
 		return value;
 	}
 
-	public static String getRecursiveProperty(Hashtable<String, String> prop,String keyOrigine) throws BiomajException {
+	public static String getRecursiveProperty(Hashtable<String, Object> prop,String keyOrigine) throws BiomajException {
 
 		if ((prop == null)||(keyOrigine == null))
 			throw new BiomajException("error.dev","Properties data are not set.");
@@ -392,11 +397,11 @@ public class BankFactory {
 		if (!prop.containsKey(keyOrigine)) {
 			String name = "";
 			if (prop.containsKey(BiomajConst.dbNameProperty))
-				name = prop.get(BiomajConst.dbNameProperty);
+				name = (String) prop.get(BiomajConst.dbNameProperty);
 			throw new BiomajException("biomaj.property.define.error",name,keyOrigine);
 		}
 
-		String value = prop.get(keyOrigine);
+		String value = (String) prop.get(keyOrigine);
 
 
 		if (value.startsWith("${"))
