@@ -464,6 +464,22 @@ public class Biomaj {
 		if (cl == null) {
 			System.exit(-2);
 		}
+		
+		/*
+		 * VERSION
+		 *********************/
+		if (cl.hasOption(VERSION_SHORT)) {	
+			System.out.println("BioMAJ version "+VERSION);
+			System.exit(0);
+		}
+		
+		/*
+		 * HELP
+		 *******************/
+		if (cl.hasOption(HELP_SHORT)) {
+			printHelp();
+			System.exit(0);
+		}
 
 		// Test general configuration
 		try {
@@ -618,19 +634,6 @@ public class Biomaj {
 				move.moveProductionDirectories(cl.getOptionValue(MOVE_PROD_SHORT));
 			}
 			
-			/*
-			 * VERSION
-			 *********************/
-			else if (cl.hasOption(VERSION_SHORT)) {	
-				System.out.println("BioMAJ version "+VERSION);
-			}
-			
-			/*
-			 * HELP
-			 *******************/
-			else if (cl.hasOption(HELP_SHORT)) {
-				printHelp();
-			}
 			
 		} catch (Exception be) {
 			System.err.println(be.getLocalizedMessage());
