@@ -32,13 +32,14 @@ import javax.xml.transform.dom.DOMSource;
 import javax.xml.transform.stream.StreamResult;
 import javax.xml.transform.stream.StreamSource;
 
-import org.apache.commons.cli2.CommandLine;
-import org.apache.commons.cli2.Group;
-import org.apache.commons.cli2.Option;
-import org.apache.commons.cli2.builder.ArgumentBuilder;
-import org.apache.commons.cli2.builder.DefaultOptionBuilder;
-import org.apache.commons.cli2.builder.GroupBuilder;
-import org.apache.commons.cli2.util.HelpFormatter;
+import org.apache.commons.cli.BasicParser;
+import org.apache.commons.cli.CommandLine;
+import org.apache.commons.cli.CommandLineParser;
+import org.apache.commons.cli.HelpFormatter;
+import org.apache.commons.cli.OptionBuilder;
+import org.apache.commons.cli.OptionGroup;
+import org.apache.commons.cli.Options;
+import org.apache.commons.cli.ParseException;
 import org.apache.log4j.Logger;
 import org.inria.biomaj.session.bank.BiomajSQLQuerier;
 import org.inria.biomaj.sql.SQLConnection;
@@ -50,7 +51,6 @@ import org.jdom.Element;
 import org.jdom.JDOMException;
 import org.jdom.input.SAXBuilder;
 import org.jdom.output.DOMOutputter;
-import org.jfree.util.Log;
 import org.xml.sax.SAXException;
 
 /**
@@ -64,29 +64,36 @@ public class Parser {
 	
 	protected static Logger logger = Logger.getLogger(Parser.class);
 
+	@SuppressWarnings("static-access")
 	public static void main(String[] args) {
-		DefaultOptionBuilder oBuilder = new DefaultOptionBuilder();
-		ArgumentBuilder aBuilder = new ArgumentBuilder();
-		GroupBuilder gBuilder = new GroupBuilder();
+//		DefaultOptionBuilder oBuilder = new DefaultOptionBuilder();
+//		ArgumentBuilder aBuilder = new ArgumentBuilder();
+//		GroupBuilder gBuilder = new GroupBuilder();
 		
-		Option dirOption = oBuilder.reset().withLongName("dir").withDescription("Directory to search the statefiles within").withArgument(
-				aBuilder.reset().withName("directory").withDescription("Directory name").withMaximum(1).create()).create();
-		Option fileOption = oBuilder.reset().withLongName("files").withDescription("List of statefiles to import").withArgument(aBuilder.reset().withName("file").withDescription("File name").withMinimum(1).create()).create();
+//		Option dirOption = OptionBuilder.withArgName("dir").withDescription("Directory to search the statefiles within").hasArgs(1).withLongOpt("dir").create();
+//		Option fileOption = OptionBuilder.withArgName("files").withDescription("List of statefiles to import").hasArgs().withLongOpt("files").create();
 //		Option batchOption = oBuilder.reset().withLongName("batch").withDescription("Execute the queries in batch mode (faster but no error reporting if the batch fails)").withRequired(false).create();
 		
 //		Group group = gBuilder.reset().withOption(dirOption).withOption(fileOption).withOption(batchOption).create();
-		Group group = gBuilder.reset().withOption(dirOption).withOption(fileOption).create();
+		OptionGroup group = new OptionGroup();
+		group.addOption(OptionBuilder.withArgName("dir").withDescription("Directory to search the statefiles within").hasArgs(1).withLongOpt("dir").create('d'));
+		group.addOption(OptionBuilder.withArgName("file1 file2 ...").withDescription("List of statefiles to import").hasArgs().withLongOpt("files").create('f'));
 		
+//		Group group = gBuilder.reset().withOption(dirOption).withOption(fileOption).create();
+		
+		Options options = new Options();
+		options.addOptionGroup(group);
+		
+		CommandLineParser parser = new BasicParser();
 		HelpFormatter help = new HelpFormatter();
-		help.setShellCommand("<command>");
-		help.setGroup(group);
 		
-		org.apache.commons.cli2.commandline.Parser parser = new org.apache.commons.cli2.commandline.Parser();
-		parser.setGroup(group);
-		parser.setHelpFormatter(help);
-		parser.setHelpTrigger("--help");
-		
-		CommandLine line = parser.parseAndHelp(args);
+		CommandLine line = null;
+		try {
+			line = parser.parse(options, args);
+		} catch (ParseException e3) {
+			System.err.println(e3.getMessage());
+			help.printHelp("import_statefiles.sh", options);
+		}
 		
 		if (line == null)
 			return;
@@ -95,9 +102,9 @@ public class Parser {
 		
 		List<String> xmlFiles = new ArrayList<String>();
 		List<String> sqlFiles = new ArrayList<String>();
-		if (line.hasOption(dirOption)) { // Get all available statefiles in directory
-
-			String path = line.getValue(dirOption).toString();
+		if (line.hasOption("dir")) { // Get all available statefiles in directory
+			
+			String path = line.getOptionValue("dir");
 			File dir;
 			if (path.startsWith("/")) // absolute path
 				dir = new File(path);
@@ -106,7 +113,7 @@ public class Parser {
 			
 			if (!dir.exists()) {
 				System.out.println("Directory does not exist : " + dir.getAbsolutePath());
-				Log.error("Directory does not exist : " + dir.getAbsolutePath());
+				logger.error("Directory does not exist : " + dir.getAbsolutePath());
 				return;
 			}
 				
@@ -123,24 +130,24 @@ public class Parser {
 					xmlFiles.add(f.getPath());
 				}
 			}
-		} else if (line.hasOption(fileOption)) { // Get statefiles list
-
-			List<?> filz = line.getValues(fileOption);
-			for (Object o : filz) {
-				if (!new File(o.toString()).exists()) {
-					System.out.println("File does not exists : " + o.toString() + ". Skipped.");
-					Log.warn("File does not exists : " + o.toString() + ". Skipped.");
+		} else if (line.hasOption("files")) { // Get statefiles list
+	
+			String[] filz = line.getOptionValues("files");
+			for (String fileName : filz) {
+				if (!new File(fileName).exists()) {
+					System.out.println("File does not exists : " + fileName + ". Skipped.");
+					logger.warn("File does not exists : " + fileName + ". Skipped.");
 					continue;
 				}
-				if (checkExistence(o.toString(), banks)) {
-					System.out.println(o.toString() + " already in the database.");
-					logger.info(o.toString() + " already in the database.");
+				if (checkExistence(fileName, banks)) {
+					System.out.println(fileName + " already in the database.");
+					logger.info(fileName + " already in the database.");
 					continue;
 				}
-				xmlFiles.add(o.toString());
+				xmlFiles.add(fileName);
 			}
-		} else {// Print help if no option was chosen
-			help.print();
+		} else { // Print help if no option was chosen
+			help.printHelp("import_statefiles.sh", options);
 			return;
 		}
 		
@@ -176,18 +183,18 @@ public class Parser {
 				trans = TransformerFactory.newInstance().newTransformer(xslSource);
 				trans.transform(source, output);
 			}
-		} catch (ParserConfigurationException e) {
-			e.printStackTrace();
-		} catch (SAXException e) {
-			e.printStackTrace();
-		} catch (IOException e) {
-			e.printStackTrace();
-		} catch (TransformerConfigurationException e) {
-			e.printStackTrace();
-		} catch (TransformerFactoryConfigurationError e) {
-			e.printStackTrace();
-		} catch (TransformerException e) {
-			e.printStackTrace();
+		} catch (ParserConfigurationException ex) {
+			ex.printStackTrace();
+		} catch (SAXException ex) {
+			ex.printStackTrace();
+		} catch (IOException ex) {
+			ex.printStackTrace();
+		} catch (TransformerConfigurationException ex) {
+			ex.printStackTrace();
+		} catch (TransformerFactoryConfigurationError ex) {
+			ex.printStackTrace();
+		} catch (TransformerException ex) {
+			ex.printStackTrace();
 		}
 
 		long start = new Date().getTime();
