@@ -38,6 +38,9 @@
  * knowledge of the CeCILL-A license and that you accept its terms.
  */
 
+/**
+ * 04/02/13: #15357, O. Sallou Fix path issue in computeRemoteFiles
+ */
 
 package org.inria.biomaj.exe.workflow;
 
@@ -385,7 +388,15 @@ public class ComputedBankWorkflowEngine extends BankSetWorkflowEngine {
 
 	protected void computeRemoteFiles() throws BiomajException {
 		BankSet bs = (BankSet) getBiomajBank();
-		String dataDir = remoteBankWorkflowEngine.getBiomajBank().getPropertiesFromBankFile().getProperty("remote.dir");
+		//String dataDir = remoteBankWorkflowEngine.getBiomajBank().getPropertiesFromBankFile().getProperty("remote.dir");
+		// Manage canonicalpath for all paths
+		String dataDir = "";
+        try {
+         dataDir = new File(remoteBankWorkflowEngine.getBiomajBank().getPropertiesFromBankFile().getProperty("remote.dir")).getCanonicalPath()+"/";
+        } catch (IOException e) {
+                throw new BiomajException(e);
+        }
+
 		StringBuilder computedRemoteFilz = new StringBuilder();
 		for (BiomajBank bb : bs.getBankList()) {
 			String currentBankName = bb.getDbName();
