@@ -106,7 +106,7 @@ public class ProcessSequentielHandler extends BiomajThread {
 	/**
 	 * @uml.property  name="listProcessToLaunched"
 	 */
-	private String listProcessToLaunched = "";
+	private String processListToLaunch = "";
 
 	/**
 	 * @uml.property  name="listenerHandler"
@@ -241,8 +241,8 @@ public class ProcessSequentielHandler extends BiomajThread {
 			return;
 		}
 		
-		if ((listProcessToLaunched == null)
-				|| (listProcessToLaunched.trim().compareTo("") == 0)) {
+		if ((processListToLaunch == null)
+				|| (processListToLaunch.trim().compareTo("") == 0)) {
 			getProject().log("No process needs to be launched for MetaProcess:["
 					+ metaProc.getName() + "]", Project.MSG_INFO);
 			setErrorOnWorkflow(false);
@@ -281,7 +281,7 @@ public class ProcessSequentielHandler extends BiomajThread {
 		}
 		// getProject().setProperty("list_process_seq",
 		// biomajBank.getPropertiesFromBankFile().getProperty(metaProc.getName()));
-		getProject().setProperty("list_process_seq", listProcessToLaunched);
+		getProject().setProperty("list_process_seq", processListToLaunch);
 		getProject().setProperty("metaprocess", metaProc.getName());
 		boolean error = false;
 		try {
@@ -369,7 +369,7 @@ public class ProcessSequentielHandler extends BiomajThread {
 	 * @uml.property name="listProcessToLaunched"
 	 */
 	public String getListProcessToLaunched() {
-		return listProcessToLaunched;
+		return processListToLaunch;
 	}
 
 	/**
@@ -378,7 +378,7 @@ public class ProcessSequentielHandler extends BiomajThread {
 	 * @uml.property name="listProcessToLaunched"
 	 */
 	public void setListProcessToLaunch(String listProcessToLaunched) {
-		this.listProcessToLaunched = listProcessToLaunched;
+		this.processListToLaunch = listProcessToLaunched;
 	}
 
 	public void deleteVolatilesFiles() {
