@@ -47,6 +47,8 @@ import java.io.FileWriter;
 import java.io.IOException;
 import java.util.Collection;
 import java.util.HashMap;
+import java.util.List;
+import java.util.Map;
 import java.util.TreeMap;
 import java.util.Vector;
 import java.util.regex.Pattern;
@@ -57,6 +59,7 @@ import org.inria.biomaj.ant.logger.BiomajConsoleLogger;
 import org.inria.biomaj.ant.task.BmajExtract;
 import org.inria.biomaj.ant.task.net.RemoteCommand;
 import org.inria.biomaj.utils.BiomajBuildException;
+import org.inria.biomaj.utils.BiomajConst;
 import org.inria.biomaj.utils.BiomajException;
 import org.inria.biomaj.utils.BiomajUtils;
 
@@ -67,7 +70,7 @@ abstract public class RemoteCommandImpl {
 	 * @uml.property  name="task"
 	 * @uml.associationEnd  multiplicity="(1 1)"
 	 */
-	private Task   task;
+	private Task task;
 
 	/**
 	 * @uml.property  name="bw"
@@ -77,7 +80,8 @@ abstract public class RemoteCommandImpl {
 	/**
 	 * @uml.property  name="server"
 	 */
-	private String server = ""; 
+	private String server = "";
+	
 	/**
 	 * UseFull to get a listing of Remote file which are ever request!
 	 * @author  ofilangi
@@ -159,7 +163,8 @@ abstract public class RemoteCommandImpl {
 	 * Commun a toutes les instanciations de protocol pour la session biomaj courante
 	 */
 	private static HashMap<String, ListingBuffer> lBuffer = null;
-
+	
+	
 	/**
 	 * Constructor
 	 * @param project
@@ -167,6 +172,8 @@ abstract public class RemoteCommandImpl {
 	 */
 	public RemoteCommandImpl(Task task) {
 		setTask(task);
+
+		
 		if (lBuffer == null)
 			lBuffer = new HashMap<String, ListingBuffer>();
 	}
@@ -174,7 +181,7 @@ abstract public class RemoteCommandImpl {
 	/*
 	 * Methode to redefine in specific protocol implementation
 	 */
-	public void init  (String server, Integer port, String username, String password) throws BiomajBuildException {
+	public void init(String server, Integer port, String username, String password) throws BiomajBuildException {
 		this.server = server;
 	}
 
@@ -182,9 +189,19 @@ abstract public class RemoteCommandImpl {
 
 	abstract public Vector<RemoteFile> listFiles(String base,String directoryToApplyLs) throws BiomajBuildException ;
 	abstract public Vector<RemoteFile> listDir(String base,String directoryToApplyLs) throws BiomajBuildException ;
+	
+	/**
+	 * List all elements in given directory (files and directories).
+	 * 
+	 * @param base
+	 * @param directoryToApplyLs
+	 * @return
+	 * @throws BiomajBuildException
+	 */
+	abstract public List<RemoteFile> listAll(String base, String directoryToApplyLs) throws BiomajBuildException;
 
 	/*
-	 * Generic Algo to get a remote listing file independantly from the protocol
+	 * Generic Algo to get a remote listing file independently from the protocol
 	 */
 
 	/**
@@ -203,22 +220,30 @@ abstract public class RemoteCommandImpl {
 		InputValidation.checkString(getTask().getProject(),remoteFiles, "the remote file regular expression");
 
 		try {
-
+			
 			Collection<RemoteFile> resultat = new Vector<RemoteFile>() ;
 			if (!bufferExist(remoteDirectory, remoteFiles, regexpExcluded)) {
-				String[] listExpression = remoteFiles.split("\\s");
-
 				TreeMap<String,RemoteFile> res = new TreeMap<String,RemoteFile>();
-				for (int i=0;i<listExpression.length;i++) {
-					log("Checking expression ["+listExpression[i]+"]...",Project.MSG_INFO);
-					getFilesMatchWithRegularExpression(remoteDirectory, "", listExpression[i], regexpExcluded,res,true);
+				
+				if (remoteFiles.equals(BiomajConst.regexpAll)) {
+					listArborescence(remoteDirectory, "", remoteFiles, res, true);
+				} else {
+					String[] listExpression = remoteFiles.split("\\s");
+					for (int i = 0; i < listExpression.length; i++) {
+						log("Checking expression ["+listExpression[i]+"]...",Project.MSG_INFO);
+						try {
+							getFilesMatchWithRegularExpression(remoteDirectory, "", listExpression[i], regexpExcluded,res,true);
+						} catch (Exception ex) {
+							throw new BiomajBuildException(getTask().getProject(), ex);
+						}
+					}
 				}
 				resultat = res.values();
 			} else {
 				log("UN BUFFER EXIST!!",Project.MSG_DEBUG);
 				resultat = getResultBuffer();
 			}
-
+			
 			bw = new BufferedWriter(new FileWriter(listingFile));  
 			writeListing(resultat);
 			bw.close();
@@ -234,19 +259,59 @@ abstract public class RemoteCommandImpl {
 		InputValidation.checkString(getTask().getProject(),remoteFiles, "the remote file regular expression");
 		TreeMap<String,RemoteFile> res = new TreeMap<String,RemoteFile>();
 
-		String[] listExpression = remoteFiles.split("\\s");
-
-		for (int i=0;i<listExpression.length;i++) {
-			log("Checking expression ["+listExpression[i]+"]...",Project.MSG_INFO);
-			getFilesMatchWithRegularExpression(remoteDirectory, "", listExpression[i], regexpExcluded,res,true);
+		if (remoteFiles.equals(BiomajConst.regexpAll)) { // List all recursively
+			listArborescence(remoteDirectory, "", regexpExcluded, res, true);
+		} else {
+			String[] listExpression = remoteFiles.trim().split("\\s+");
+			
+			for (int i = 0; i < listExpression.length; i++) {
+				log("Checking expression ["+listExpression[i]+"]...",Project.MSG_INFO);
+				
+				try {
+					getFilesMatchWithRegularExpression(remoteDirectory, "", listExpression[i], regexpExcluded,res,true);
+				} catch (Exception ex) {
+					ex.printStackTrace();
+					throw new BiomajBuildException(getTask().getProject(), ex);
+				}
+			}
 		}
 
 		setResultBuffer(remoteDirectory, remoteFiles, regexpExcluded, res.values());
 
 		return res.values();
 	}
+	
+	protected void listArborescence(final String remoteDirectory, String relativePath, final String excludedFiles, Map<String, RemoteFile> res, boolean log) {
+		if (log)
+			log("Listing arboresence under '" + remoteDirectory + "/" + relativePath + "' omitting '" + excludedFiles + "'", Project.MSG_VERBOSE);
+		
+		List<RemoteFile> filz = listAll(remoteDirectory, relativePath);
+		int total = filz.size();
+		int  i = 1;
+		for (RemoteFile file : filz) {
+			
+			if (log) {
+				log(BiomajConsoleLogger.NOT_KEEP_LINE_ON_CONSOLE + "[" + (i++) + "/" + total + "]", Project.MSG_INFO);
+			}
+			
+			if (match(file.getAbsolutePath(), ".*", excludedFiles)) {
+				if (file.isDir()) {
+					if (log)
+						log("Listing sub dir : " + remoteDirectory, Project.MSG_VERBOSE);
+					
+					final String newPath = relativePath.trim().isEmpty() ? file.getName() : relativePath + "/" + file.getName();
+					
+					listArborescence(remoteDirectory, newPath, excludedFiles, res, log);
+				} else {
+					log("Adding to list :" + file.toString(), Project.MSG_VERBOSE);
+					res.put(file.getAbsolutePath(), file);
+				}
+			}
+		}
+	}
 
-	private void getFilesMatchWithRegularExpression(String remoteDirectory,String path,String regExpr,String regExprExclu,TreeMap<String,RemoteFile> resultat,boolean logPercent) throws BiomajBuildException {
+	protected void getFilesMatchWithRegularExpression(final String remoteDirectory, final String path, final String regExpr, final String regExprExclu, final Map<String,RemoteFile> resultat, final boolean logPercent) throws BiomajBuildException {
+		
 		if (logPercent)
 			log("Searching files in root directory....",Project.MSG_VERBOSE);
 
@@ -254,12 +319,14 @@ abstract public class RemoteCommandImpl {
 			log("argument 'resulat' from getFilesMatchWithRegularExpression can't be set null",Project.MSG_ERR);
 			throw new BiomajBuildException(getTask().getProject(),"",new Exception());
 		}
+		
 		//Il n'y a pas de repertoire dans l'expression reguliere
 		if (!regExpr.contains("/")) {
 			if (!path.endsWith("/..") && !path.endsWith("/.") && !path.equals(".") && !path.equals("..")) {
 				if (logPercent)
 					log("Biomaj is creating a file list...",Project.MSG_VERBOSE);
 				
+				
 				Vector<RemoteFile> lFiles = listFiles(remoteDirectory,path);
 				int compteur = 0;
 				for (RemoteFile f : lFiles) {
@@ -277,58 +344,62 @@ abstract public class RemoteCommandImpl {
 						if (!resultat.containsKey(f.getAbsolutePath())){
 							resultat.put(f.getAbsolutePath(),f);
 						}
-						/*else {
-								bw.write(f.toString());
-								bw.newLine();
-							}*/
 					}
 				}
 			}
 			return;
 		}
 
+		
+		if (regExpr.equals(BiomajConst.regexpAll)) {
+			listArborescence(remoteDirectory, path, regExprExclu, resultat, false);
+			return;
+		}
+		
 		//On decoupe en sous repertoire et fichier
-		String[] decomposeDirectory = regExpr.split("/");	
-		/*
-		for (int i=0;i<decomposeDirectory.length;i++)
-			System.out.println(decomposeDirectory[i]);
-		 */
-		String newRegExpr = regExpr.substring(decomposeDirectory[0].length()+1);
+		String[] decomposeDirectory = regExpr.split("/");
+		// File regexp
+		final String newRegExpr = regExpr.substring(decomposeDirectory[0].length()+1);
 
 		if (logPercent)
 			log("Biomaj is creating a list of sub-directory...",Project.MSG_VERBOSE);
 
 		if (!path.equals(".") && !path.equals("..")) {
+			
+			
 			Vector<RemoteFile> lDirs = listDir(remoteDirectory,path);
 			
+			
 			if (logPercent)
 				log("Searching files in sub-directory...",Project.MSG_VERBOSE);
 	
 			int compteur = 0;
+			int total = lDirs.size() * 100;
 			for (RemoteFile d : lDirs) {
+				
 				compteur++;
-				if (match(d.getAbsolutePath(),decomposeDirectory[0],regExprExclu))
-				{
+				if (match(d.getName(),decomposeDirectory[0],regExprExclu)) {
 					if (logPercent) {
-						float a = ((float)compteur/ (float)lDirs.size())*100;
+						float a = (float) (compteur/ total);
 						log(BiomajConsoleLogger.NOT_KEEP_LINE_ON_CONSOLE+"["+Integer.toString((int)a)+"%]",Project.MSG_INFO);
 					}
 					log("Expr:"+regExpr,Project.MSG_VERBOSE);
 					log(d.getAbsolutePath()+" match with "+decomposeDirectory[0],Project.MSG_VERBOSE);
 					log("newExpr:"+newRegExpr,Project.MSG_VERBOSE);
-					String newPath = path;
-					if (newPath.compareTo("")!=0)
-						newPath = newPath+"/"+d.getName();
-					else
-						newPath = d.getName();
-					getFilesMatchWithRegularExpression(remoteDirectory,newPath,newRegExpr,regExprExclu,resultat,false);
+					
+					final String newPath = path.trim().isEmpty() ? d.getName() : path + "/" + d.getName();
+					getFilesMatchWithRegularExpression(remoteDirectory, newPath, newRegExpr, regExprExclu, resultat, false);
+//					if (registeredException.get(bank) == null) {
+//						startThreadedListing(false, logPercent, newRegExpr, resultat, regExprExclu, newPath, remoteDirectory);
+//					} else {
+//						throw new BiomajBuildException(task.getProject(), registeredException.get(bank));
+//					}
 				}
 			}
 		}
 	}
-
-
-	private boolean match (String filePath, String expr, String exprExc) {
+	
+	private boolean match(String filePath, String expr, String exprExc) {
 		final Pattern p = Pattern.compile(expr);
 		boolean exclu = false;
 		//log("filePath:"+filePath+"  expr:"+expr+" exprExclu:"+exprExc,Project.MSG_INFO);
@@ -340,10 +411,10 @@ abstract public class RemoteCommandImpl {
 			}
 		}
 
-		if (p.matcher(filePath).find()&&(!exclu)){
+		if (p.matcher(filePath).matches() && !exclu) {
 			log(filePath+" match with:"+expr,Project.MSG_VERBOSE);
 			return true;
-		} 	
+		}
 
 		log(filePath+" not match! with:"+expr +" exclude:"+Boolean.toString(exclu),Project.MSG_VERBOSE);
 		return false;
@@ -372,7 +443,7 @@ abstract public class RemoteCommandImpl {
 		}
 
 		boolean ret = getFileWithImpl(remoteDirectory,nameFile,targetDirectory,targetName);
-
+		
 		if (!ret)
 			return ret;
 
@@ -385,7 +456,7 @@ abstract public class RemoteCommandImpl {
 			if (BmajExtract.check(f,getTask())) {
 				getTask().log("compressed file is check!",Project.MSG_VERBOSE);
 			} else {
-				getTask().log("compressed file is corruped!",Project.MSG_VERBOSE);
+				getTask().log("compressed file is corrupted!",Project.MSG_VERBOSE);
 				return false;
 			}
 		}
