@@ -25,7 +25,7 @@ import org.inria.biomaj.utils.BiomajUtils;
  * Class that requests various information from the database.
  * 
  * @author rsabas
- *
+ * @author tuco (Emmanuel Quevillon) SQL queries updates
  */
 public class BiomajSQLQuerier {
 	
@@ -454,7 +454,9 @@ public class BiomajSQLQuerier {
 		int bankId = getBankId(bankName);
 		if (bankId < 0)
 			return null;
-		
+		// Varies between 0.28 sec and 2 sec
+		// New query between 0.01 and 0.12 sec
+		/*
 		String query = "SELECT * FROM bank,configuration,localInfo,remoteInfo WHERE idconfiguration IN " +
 				"(SELECT ref_idconfiguration FROM updateBank WHERE ref_idconfiguration IN " +
 				"(SELECT idconfiguration FROM configuration WHERE ref_idbank=" + bankId + ") AND " +
@@ -463,7 +465,17 @@ public class BiomajSQLQuerier {
 				"AND idremoteinfo=ref_idremoteinfo " +
 				"AND idlocalinfo=ref_idlocalinfo " +
 				"AND idbank = ref_idbank";
-		
+		*/
+		// We only want one result (getBankInfo(rs))
+		  String query = "SELECT b.*,c.*,lI.*,rI.* FROM bank b " +
+		      "JOIN configuration c ON c.ref_idbank = b.idbank " +
+		      "JOIN localInfo lI ON lI.idlocalInfo = c.ref_idlocalInfo " +
+		      "JOIN remoteInfo rI ON rI.idremoteInfo = c.ref_idremoteInfo " +
+		      "JOIN updateBank uB ON uB.ref_idconfiguration = c.idconfiguration " +
+		      "WHERE b.idbank = " + bankId + " " +
+		      "ORDER BY uB.startTime DESC LIMIT 1";
+
+
 		Statement stat = connection.getStatement();
 		ResultSet rs = connection.executeQuery(query, stat);
 		Map<String, String> res = getBankInfo(rs);
@@ -560,7 +572,7 @@ public class BiomajSQLQuerier {
 		Map<String, String> res = null;
 		ResultSet result = connection.executeQuery(query, stat);
 		res = getBankInfo(result);
-		
+
 		SQLConnectionFactory.closeConnection(stat);
 		return res;
 	}
@@ -774,6 +786,7 @@ public class BiomajSQLQuerier {
 	 */
 	public static synchronized List<Map<String, String>> getBankUpdates(String bankName, boolean withUpdate) {
 		
+		/* Better query performance : tuco 24.10.2013
 		String query;
 		if (withUpdate)
 			query = "SELECT * FROM updateBank WHERE isUpdated=true AND ";
@@ -782,7 +795,15 @@ public class BiomajSQLQuerier {
 		query += "ref_idconfiguration IN " +
 				"(SELECT idconfiguration FROM configuration WHERE ref_idbank=" +
 				"(SELECT idbank FROM bank WHERE name='" + bankName + "')) ORDER BY startTime DESC;";
-		
+		*/
+		String query = "SELECT uB.* FROM updateBank uB " +
+		    "JOIN configuration c ON c.idconfiguration = uB.ref_idconfiguration " +
+		    "JOIN bank b ON b.idbank = c.ref_idbank " +
+		    "WHERE b.name = '" + bankName + "' ";
+		if (withUpdate)
+		    query += "AND isUpdated = true ";
+		query += "ORDER BY uB.startTime DESC";
+
 		Statement stat = connection.getStatement();
 		
 		List<Map<String, String>> info = new ArrayList<Map<String,String>>();
@@ -914,10 +935,16 @@ public class BiomajSQLQuerier {
 	 * @return
 	 */
 	public static synchronized String getLatestSessionDate(int bankId) {
+	    /* SQL Query improvment 
+	       Tuco 23.10.2013
 		String query = "SELECT max(startTime) FROM session WHERE ref_idupdateBank IN (" +
 				"SELECT idupdateBank FROM updateBank WHERE ref_idconfiguration IN (" +
 				"SELECT idconfiguration FROM configuration WHERE ref_idbank=" + bankId + "));";
-		
+	    */
+	    String query = "SELECT max(s.startTime) FROM session s " +
+		"JOIN updateBank uB ON uB.idupdateBank = s.ref_idupdateBank " +
+		"JOIN configuration c ON c.idconfiguration = uB.ref_idconfiguration " +
+		"WHERE c.ref_idbank = " + bankId;
 		Statement stat = connection.getStatement();
 		try {
 			ResultSet rs = connection.executeQuery(query, stat);
@@ -943,10 +970,15 @@ public class BiomajSQLQuerier {
 	public static synchronized List<Map<String, String>> getSessionTasks(long sessionId) {
 		
 		List<Map<String, String>> sessionTasks = new ArrayList<Map<String,String>>();
-		
+		/* SQL query improvment
+		   Tuco  23.10.2013
 		String query = "SELECT * from sessionTask WHERE idsessionTask IN " +
 				"(SELECT ref_idsessionTask FROM session_has_sessionTask WHERE " +
 				"ref_idsession =" + sessionId + ");";
+		*/
+		String query = "SELECT * FROM sessionTask sT " +
+		    "JOIN session_has_sessionTask shsT ON shsT.ref_idsessionTask = sT.idsessionTask " +
+		    "WHERE shsT.ref_idsession = " + sessionId;
 		Statement stat = connection.getStatement();
 		try {
 			ResultSet result = connection.executeQuery(query, stat);
@@ -1095,11 +1127,21 @@ public class BiomajSQLQuerier {
 		
 		for (Map<String, String> update : updates) {
 //			Map<String, String> update = getLatestUpdate(bankName, true);
+		    /* SQL qeury improvment
+		       Original query time : 1min23sec
+		       New query time      : 0.12 sec
+		       Tuco  24.10.2013
 			String query = "SELECT * FROM file WHERE idfile IN (SELECT ref_idfile FROM sessionTask_has_file WHERE " +
 					"ref_idsessionTask IN (SELECT idsessionTask FROM sessionTask WHERE taskType='makeRelease' AND idsessionTask IN " +
 					"(SELECT ref_idsessionTask FROM session_has_sessionTask WHERE ref_idsession IN " +
 					"(SELECT idsession FROM session WHERE ref_idupdateBank=" + update.get(UPDATE_ID) + "))))";
-			
+		    */
+		    String query = "SELECT f.* FROM file f " +
+			"JOIN sessionTask_has_file sThf ON sThf.ref_idfile = f.idfile " +
+			"JOIN sessionTask sT ON sT.idsessionTask = sThf.ref_idsessionTask " +
+			"JOIN session_has_sessionTask shsT ON shsT.ref_idsessionTask = sT.idsessionTask " +
+			"JOIN session s on s.idsession = shsT.ref_idsession " +
+			"WHERE sT.taskType='makeRelease' AND  s.ref_idupdateBank = " + update.get(UPDATE_ID);
 			Statement stat = connection.getStatement();
 			ResultSet rs = connection.executeQuery(query, stat);
 			filz = getFiles(rs);
@@ -1181,10 +1223,17 @@ public class BiomajSQLQuerier {
 	 * @return list that contains first the warnings then the errors. 
 	 */
 	public static synchronized List<List<String>> getTaskMessages(int taskId) {
-		
+	    /* SQL query improvment
+	       Original query time : 0.24sec
+	       New query time      : 0.06
+	       Tuco 24.10.2013
 		String query = "SELECT * from message WHERE idmessage IN " +
 				"(SELECT ref_idmessage FROM sessionTask_has_message WHERE " +
 				"ref_idsessionTask =" + taskId + ");";
+	    */
+		String query = "SELECT m.* FROM message m " +
+		    "JOIN sessionTask_has_message sThm ON sThm.ref_idmessage = m.idmessage " +
+		    "WHERE sThm.ref_idsessionTask = " + taskId;
 		Statement stat = connection.getStatement();
 
 		ResultSet result = connection.executeQuery(query, stat);
@@ -1203,12 +1252,19 @@ public class BiomajSQLQuerier {
 	 * @return list that contains first the warnings then the errors. 
 	 */
 	public static synchronized List<List<String>> getProcessMessages(int processId) {
-		
+	    /* SQL query improvment
+	       Original query time :
+	       New query time      :
+	       Tuco 24.10.2013
 		String query = "SELECT * from message WHERE idmessage IN " +
 				"(SELECT ref_idmessage FROM process_has_message WHERE " +
 				"ref_idprocess =" + processId + ");";
-		Statement stat = connection.getStatement();
 
+	    */
+	    String query = "SELECT m.* FROM message m " +
+		"JOIN process_has_message phm ON phm.ref_idmessage = m.idmessage " +
+		"WHERE phm.ref_idprocess = " + processId;
+		Statement stat = connection.getStatement();
 		ResultSet result = connection.executeQuery(query, stat);
 		List<List<String>> mess = getMessages(result);
 		SQLConnectionFactory.closeConnection(stat);
@@ -1264,10 +1320,15 @@ public class BiomajSQLQuerier {
 	 * @return list that contains first the warnings then the errors. 
 	 */
 	public static synchronized List<List<String>> getSessionMessages(long sessionId) {
-		
+	    /* SQL query improvment 
+	       Tuco 24.10.2013
 		String query = "SELECT * from message WHERE idmessage IN " +
 				"(SELECT ref_idmessage FROM session_has_message WHERE " +
 				"ref_idsession =" + sessionId + ");";
+	    */
+	        String query = "SELECT m.* FROM message m " +
+		    "JOIN session_has_message shm ON shm.ref_idmessage = m.idmessage " +
+		    "WHERE shm.ref_idsession = " + sessionId;
 		Statement stat = connection.getStatement();
 
 		ResultSet result = connection.executeQuery(query, stat);
@@ -1322,12 +1383,17 @@ public class BiomajSQLQuerier {
 	 * @return list that contains first the warnings then the errors. 
 	 */
 	public static synchronized List<List<String>> getMetaprocessMessages(String metaId) {
-
+	    /* SQL query improvment
+	       Tuco 24.10.2013
 		String query = "SELECT * from message WHERE idmessage IN " +
 				"(SELECT ref_idmessage FROM metaprocess_has_message WHERE " +
 				"ref_idmetaprocess='" + metaId + "');";
+	    */
+	        String query = "SELECT m.* FROM message m " +
+		    "JOIN metaprocess_has_message mphm ON mphm.ref_idmessage = m.idmessage " +
+		    "WHERE mphm.ref_idmetaprocess = '" + metaId + "'";
+
 		Statement stat = connection.getStatement();
-		
 		ResultSet result = connection.executeQuery(query, stat);
 		List<List<String>> mess = getMessages(result);
 		SQLConnectionFactory.closeConnection(stat);
@@ -1874,9 +1940,15 @@ public class BiomajSQLQuerier {
 				// Delete files sessiontask on db
 				deleteTaskFiles(idTask);
 				// Delete files on disk
+				/*
+				  Tuco increase time execution
 				query = "SELECT location FROM file WHERE idfile IN " +
 						"(SELECT ref_idfile FROM sessionTask_has_file WHERE " +
 						"ref_idsessionTask=" + idTask + ")";
+				*/
+				query = "SELECT location FROM file f " +
+				    "JOIN sessionTask_has_file sThf ON f.idfile = sThf.ref_idfile " +
+				    "WHERE sThf.ref_idsessionTask = " + idTask;
 				Statement stat4 = connection.getStatement();
 				deleteFiles(connection.executeQuery(query, stat4));
 				SQLConnectionFactory.closeConnection(stat4);
@@ -1932,10 +2004,15 @@ public class BiomajSQLQuerier {
 	 * @param idTask
 	 */
 	public static synchronized void deleteTaskFiles(long idTask) {		
+	    /* SQL query improvment, run much faster
+	       Tuco : 23.10.2013
 		String query = "DELETE FROM file WHERE idfile IN " +
 				"(SELECT ref_idfile FROM sessionTask_has_file " +
 				"WHERE ref_idsessionTask=" + idTask + ");";
-
+	    */
+	    String query = "DELETE f FROM file f " +
+		"JOIN sessionTask_has_file sThf ON sThf.ref_idfile = f.idfile " +
+		"WHERE sThf.ref_idsessionTask = " + idTask;
 		Statement stat = connection.getStatement();
 		connection.executeUpdate(query, stat);
 		SQLConnectionFactory.closeConnection(stat);
@@ -1966,10 +2043,15 @@ public class BiomajSQLQuerier {
 	 * @param idMeta
 	 */
 	private static void deleteMetaprocessMessages(String idMeta) {
+	    /* SQL query improvment
+	       Tuco 23.10.2013
 		String query = "DELETE FROM message WHERE idmessage IN " +
 				"(SELECT ref_idmessage FROM metaprocess_has_message " +
 				"WHERE ref_idmetaprocess='" + idMeta + "');";
-
+	    */
+	    String query = "DELETE m FROM message m " + 
+		"JOIN metaprocess_has_message mphm on mphm.ref_idmessage = m.idmessage " +
+		"WHERE mphm.ref_idmetaprocess = '" + idMeta + "'";
 		Statement stat = connection.getStatement();
 		connection.executeUpdate(query, stat);
 		SQLConnectionFactory.closeConnection(stat);
@@ -1983,10 +2065,15 @@ public class BiomajSQLQuerier {
 	 * @param idMeta
 	 */
 	public static synchronized void deleteProcessMessages(long idProcess) {
+	    /* SQL query improvment
+	       Tuco 24.10.2013
 		String query = "DELETE FROM message WHERE idmessage IN " +
 				"(SELECT ref_idmessage FROM process_has_message " +
 				"WHERE ref_idprocess=" + idProcess + ");";
-
+	    */
+	        String query = "DELETE m FROM message m " + 
+		    "JOIN process_has_message phm ON phm.ref_idmessage = m.idmessage " +
+		    "WHERE phm.ref_idprocess = " + idProcess;
 		Statement stat = connection.getStatement();
 		connection.executeUpdate(query, stat);
 		SQLConnectionFactory.closeConnection(stat);		
@@ -1999,20 +2086,30 @@ public class BiomajSQLQuerier {
 	 * @param idMeta
 	 */
 	public static synchronized void deleteTaskMessages(long idTask) {
+	    /* SQL query improvment 
+	       Tuco 24.10.2013
 		String query = "DELETE FROM message WHERE idmessage IN " +
 				"(SELECT ref_idmessage FROM sessionTask_has_message " +
 				"WHERE ref_idsessionTask=" + idTask + ");";
-
+	    */
+	        String query = "DELETE m FROM message m " +
+		    "JOIN sessionTask_has_message sThm ON sThm.ref_idmessage = m.idmessage " +
+		    "WHERE sThm.ref_idsessionTask = " + idTask;
 		Statement stat = connection.getStatement();
 		connection.executeUpdate(query, stat);
 		SQLConnectionFactory.closeConnection(stat);
 	}
 	
 	public static synchronized void deleteSessionMessages(long idSession) {
+	    /* SQL query improvment
+	       Tuco 24.10.2013
 		String query = "DELETE FROM message WHERE idmessage IN " +
 				"(SELECT ref_idmessage FROM session_has_message " +
 				"WHERE ref_idsession=" + idSession + ");";
-
+	    */
+	        String query = "DELETE m FROM message m  " +
+		    "JOIN session_has_message shm ON shm.ref_idmessage = m.idmessage " +
+		    "WHERE shm.ref_idsession = " + idSession;
 		Statement stat = connection.getStatement();
 		connection.executeUpdate(query, stat);
 		SQLConnectionFactory.closeConnection(stat);
@@ -2026,27 +2123,54 @@ public class BiomajSQLQuerier {
 		Statement stat = connection.getStatement();
 		// Delete sessionTask files
 		
+		/* Tuco 23/10.2013 : Improved SQL query to increase execution time
+		   This long time execution caused 'Lock wait timeout exceeded' error
+		   if more than one bank tried to execute the query to delete files
+		   row from the database.
+
+		             Original query time execution : > 55 sec
+			     New query time execution      : 0.10 sec
+
 		String query = "DELETE FROM file WHERE idfile IN " +
 				"(SELECT ref_idfile FROM sessionTask_has_file WHERE ref_idsessionTask IN " +
 				"(SELECT ref_idsessionTask FROM session_has_sessionTask WHERE ref_idsession=" +
 				"(SELECT session FROM productionDirectory WHERE idproductionDirectory=" + productionDirectoryId +
 				")))";
-		
+
+		*/
+		String query = "DELETE f FROM file f " + 
+		    "JOIN sessionTask_has_file sThf ON sThf.ref_idfile = f.idfile " +
+		    "JOIN sessionTask sT ON sT.idsessionTask = sThf.ref_idsessionTask " +
+		    "JOIN session_has_sessionTask shsT ON shsT.ref_idsessionTask = sT.idsessionTask " +
+		    "JOIN productionDirectory pD ON pD.session = shsT.ref_idsession " +
+		    "WHERE idproductionDirectory = " + productionDirectoryId;
+
 		BiomajLogger.getInstance().log("Deleting sessionTask files", BiomajLogger.INFO_LEVEL);
 		connection.executeUpdate(query, stat);
 		
 		// Delete process files
+		/* Original query Time execution : 12 < time > 16 sec
+		   New query time execution      : 0.17 sec
 		query = "DELETE FROM file WHERE ref_idprocess IN " +
 				"(SELECT idprocess FROM process WHERE ref_idmetaprocess IN " +
 				"(SELECT idmetaprocess FROM metaprocess WHERE ref_idsessionTask IN " +
 				"(SELECT ref_idsessionTask FROM session_has_sessionTask WHERE ref_idsession=" +
 				"(SELECT session FROM productionDirectory WHERE idproductionDirectory=" + productionDirectoryId +
 				"))))";
-		
+		*/
+		query = "DELETE f FROM file f " +
+		    "JOIN process p ON p.idprocess = f.ref_idprocess " +
+		    "JOIN metaprocess mp ON mp.idmetaprocess = p.ref_idmetaprocess " +
+		    "JOIN session_has_sessionTask shsT ON shsT.ref_idsessionTask = mp.ref_idsessionTask " +
+		    "JOIN productionDirectory pD ON pD.session = shsT.ref_idsession " +
+		    "WHERE pD.idproductionDirectory = " + productionDirectoryId;
+
 		BiomajLogger.getInstance().log("Deleting process files", BiomajLogger.INFO_LEVEL);
 		connection.executeUpdate(query, stat);
 		
 		// Process messages
+		/* Original query Time execution : 0.08 sec
+		   New query time execution      : 0.0  sec
 		query = "DELETE FROM message WHERE idmessage IN " +
 				"(SELECT ref_idmessage FROM process_has_message WHERE ref_idprocess IN " +
 				"(SELECT idprocess FROM process WHERE ref_idmetaprocess IN " +
@@ -2054,37 +2178,70 @@ public class BiomajSQLQuerier {
 				"(SELECT ref_idsessionTask FROM session_has_sessionTask WHERE ref_idsession=" +
 				"(SELECT session FROM productionDirectory WHERE idproductionDirectory=" + productionDirectoryId +
 				")))))";
-		
+		*/
+		query = "DELETE m FROM message m " +
+		    "JOIN process_has_message phm ON phm.ref_idmessage = m.idmessage " +
+		    "JOIN process p ON p.idprocess = phm.ref_idprocess " +
+		    "JOIN metaprocess mp ON mp.idmetaprocess = p.ref_idmetaprocess " +
+		    "JOIN session_has_sessionTask shsT ON shsT.ref_idsessionTask = mp.ref_idsessionTask " +
+		    "JOIN productionDirectory pD ON pD.session = shsT.ref_idsessionTask " +
+		    "WHERE pD.idproductionDirectory = " + productionDirectoryId;
 		BiomajLogger.getInstance().log("Deleting process messages", BiomajLogger.INFO_LEVEL);
 		connection.executeUpdate(query, stat);
 		
 		// Metaprocess messages
+		/*
+		  Original query : 0.02 sec (empty set)
+		  New query      : 0.02 sec (empty set)
 		query = "DELETE FROM message WHERE idmessage IN " +
 				"(SELECT ref_idmessage FROM metaprocess_has_message WHERE ref_idmetaprocess IN " +
 				"(SELECT idmetaprocess FROM metaprocess WHERE ref_idsessionTask IN " +
 				"(SELECT ref_idsessionTask FROM session_has_sessionTask WHERE ref_idsession=" +
 				"(SELECT session FROM productionDirectory WHERE idproductionDirectory=" + productionDirectoryId +
 				"))))";
-		
+		*/
+		query = "DELETE m FROM message m " +
+		    "JOIN metaprocess_has_message mphm ON mphm.ref_idmessage = m.idmessage " +
+		    "JOIN metaprocess mp ON mp.idmetaprocess = mphm.ref_idmetaprocess " +
+		    "JOIN session_has_sessionTask shsT ON shsT.ref_idsessionTask = mp.ref_idsessionTask " +
+		    "JOIN productionDirectory pD ON pD.session = shsT.ref_idsession " +
+		    "WHERE pD.idproductionDirectory = " + productionDirectoryId;
+
 		BiomajLogger.getInstance().log("Deleting metaprocess messages", BiomajLogger.INFO_LEVEL);
 		connection.executeUpdate(query, stat);
 		
 		// SessionTask messages
+		/*
+		  Original query : 0.04 sec (1 row)
+		  New query      : 0.00 sec (1 row)
 		query = "DELETE FROM message WHERE idmessage IN " +
 				"(SELECT ref_idmessage FROM sessionTask_has_message WHERE ref_idsessionTask IN " +
 				"(SELECT ref_idsessionTask FROM session_has_sessionTask WHERE ref_idsession=" +
 				"(SELECT session FROM productionDirectory WHERE idproductionDirectory=" + productionDirectoryId +
 				")))";
-		
+		*/
+		query = "DELETE m FROM message m " +
+		    "JOIN sessionTask_has_message sThm ON sThm.ref_idmessage = m.idmessage " +
+		    "JOIN session_has_sessionTask shsT ON shsT.ref_idsessionTask = sThm.ref_idsessionTask " +
+		    "JOIN productionDirectory pD ON pD.session = shsT.ref_idsession " +
+		    "WHERE pD.idproductionDirectory = " + productionDirectoryId;
+
 		BiomajLogger.getInstance().log("Deleting sessionTask messages", BiomajLogger.INFO_LEVEL);
 		connection.executeUpdate(query, stat);
 		
 		// Session messages
+		/*
+		  Original query : 0.12 sec (1 row)
+		  New query      : 0.00 sec (1 row)
 		query = "DELETE FROM message WHERE idmessage IN " +
 				"(SELECT ref_idmessage FROM session_has_message WHERE ref_idsession=" +
 				"(SELECT session FROM productionDirectory WHERE idproductionDirectory=" + productionDirectoryId +
 				"))";
-		
+		*/
+		query = "DELETE m FROM message m " +
+		    "JOIN session_has_message shm ON shm.ref_idmessage = m.idmessage " +
+		    "JOIN productionDirectory pD ON pD.session = shm.ref_idsession " +
+		    "WHERE pD.idproductionDirectory = " + productionDirectoryId;
 		BiomajLogger.getInstance().log("Deleting session messages", BiomajLogger.INFO_LEVEL);
 		connection.executeUpdate(query, stat);
 		
