@@ -430,8 +430,9 @@ public class Session implements Comparable<Session>{
 
 	public GeneralWorkflowTask getLastTask() {
 		for (int i=Session.REMOVEPROCESS;i>=Session.PREPROCESS;i--) {
-			if (workflowtasks.containsKey(i))
+			if (workflowtasks.containsKey(i)) {
 				return workflowtasks.get(i);
+			}
 		}
 		return null;
 	}
