@@ -60,6 +60,8 @@ public class BiomajInformation {
 	public static final String  OPTION_TEST    = ".option.test";
 	public static final String  OPTION_DECOMP  = ".option.uncomp";
 	public static final String  OPTION_OUTPUT  = ".option.output";
+	
+	public static String CONF_LOCATION = BiomajUtils.getBiomajRootDirectory();
 
 
 	protected final static String ENGINE_SECTION="ENGINE";
@@ -70,7 +72,7 @@ public class BiomajInformation {
 	/**
 	 * Applications section
 	 */
-	private static Hashtable<String, Hashtable<String,String> > _sections; 
+	private static Hashtable<String, Hashtable<String,String>> _sections; 
 
 	private String envBmaj;
 
@@ -89,10 +91,10 @@ public class BiomajInformation {
 		_sections = new Hashtable<String, Hashtable<String,String>>(); 
 		envBmaj = BiomajUtils.getBiomajRootDirectory();
 
-		File f = new File(envBmaj+"/"+BiomajConst.nameGeneralConf);
+		File f = new File(CONF_LOCATION+"/"+BiomajConst.nameGeneralConf);
 		try {
 			if (!f.exists()) {
-				System.out.println("The file ["+envBmaj+"/"+BiomajConst.nameGeneralConf+"] does not exist!");
+				System.out.println("The file ["+CONF_LOCATION+"/"+BiomajConst.nameGeneralConf+"] does not exist!");
 				System.out.println("BioMAJ create a new file. Edit the file to change input/output directories.");
 				BufferedWriter bw = new BufferedWriter (new FileWriter(f));
 				bw.write("# Created by BioMAJ "+Biomaj.VERSION);bw.newLine();
@@ -140,7 +142,6 @@ public class BiomajInformation {
 				bw.write("bunzip.bin="+which("bunzip2"));bw.newLine();
 				bw.write("bunzip.case=.bz2");bw.newLine();
 				bw.write("bunzip.option.uncomp=-f");bw.newLine();
-				bw.write("bunzip.option.output=-c");bw.newLine();
 				bw.write("bunzip.option.test=-t");bw.newLine();
 
 				bw.newLine();
@@ -270,16 +271,16 @@ public class BiomajInformation {
 		} else if (!_sections.get(DIRECTORIES_SECTION).containsKey(BiomajInformation.TMPDIR)) {
 			System.err.println("Property ["+BiomajInformation.TMPDIR+"] is not defined in "+BiomajConst.nameGeneralConf);
 			return false;
-		}  else if (!_sections.get(APPLICATIONS_SECTION).containsKey(BiomajInformation.WGET)) {
+		}/*  else if (!_sections.get(APPLICATIONS_SECTION).containsKey(BiomajInformation.WGET)) {
 			System.err.println("Property ["+BiomajInformation.WGET+"] is not defined in "+BiomajConst.nameGeneralConf);
 			return false;
-		} 
+		}*/
 
-		if ("".compareTo(which(getProperty(BiomajInformation.WGET)))==0)
+		/*if ("".compareTo(which(getProperty(BiomajInformation.WGET)))==0)
 		{
 			System.err.println("BioMAJ does not find executable :"+ getProperty(BiomajInformation.WGET));
 			return false;
-		}
+		}*/
 
 		if (_sections.get(APPLICATIONS_SECTION).containsKey(BiomajInformation.LIST_BIN_UNCOMPRESS)) {
 			String[] listBinUncompress = _sections.get(APPLICATIONS_SECTION).get(BiomajInformation.LIST_BIN_UNCOMPRESS).split(",");
