@@ -1,5 +1,6 @@
 package org.inria.biomaj.sql;
 
+import java.sql.PreparedStatement;
 import java.sql.ResultSet;
 import java.sql.Statement;
 
@@ -38,9 +39,13 @@ public interface SQLConnection {
 	 * Creates the database.
 	 * This method should be called only if you want to reset the database.
 	 * 
+	 * @param adminLogin 
+	 * @param adminPasswd
+	 * @param adminMail
+	 * 
 	 * @return success ?
 	 */
-	public boolean createDB();
+	public boolean createDB(String adminLogin, String adminPasswd, String adminMail);
 	
 	/**
 	 * Creates a connection to the db and return a statement object attached to it.
@@ -48,6 +53,14 @@ public interface SQLConnection {
 	 * @return Created statement
 	 */
 	public Statement getStatement();
+	
+	/**
+	 * Creates a connection to the db and return a prepared statement object attached to it.
+	 * 
+	 * @param query parameterized query
+	 * @return Created statement
+	 */
+	public PreparedStatement getPreparedStatement(String query);
 
 	
 	/**
