@@ -41,6 +41,7 @@
 
 package org.inria.biomaj.utils;
 
+import java.io.BufferedOutputStream;
 import java.io.BufferedReader;
 import java.io.BufferedWriter;
 import java.io.File;
@@ -454,14 +455,14 @@ public class BiomajUtils  {
 	public static void copy(File source, File dest) throws IOException {
 		createSubDirectories(getRelativeDirectory(dest.getAbsolutePath()));
 		FileInputStream fis  = new FileInputStream(source);
-		FileOutputStream fos = new FileOutputStream(dest);
+		BufferedOutputStream bos = new BufferedOutputStream(new FileOutputStream(dest));
 		byte[] buf = new byte[1024];
 		int i = 0;
-		while((i=fis.read(buf))!=-1) {
-			fos.write(buf, 0, i);
+		while ((i = fis.read(buf)) > 0) {
+			bos.write(buf, 0, i);
 		}
 		fis.close();
-		fos.close();
+		bos.close();
 		
 		dest.setLastModified(source.lastModified());
 	}
@@ -881,7 +882,6 @@ public class BiomajUtils  {
 	public static boolean fillConfig(String dbName, Configuration config) {
 		
 		try {
-			
 			BankFactory bf = new BankFactory();
 			BiomajBank b = bf.createBank(dbName,false);
 			
@@ -907,12 +907,10 @@ public class BiomajUtils  {
 			config.setName(dbName);
 			config.setNbVersionManagement(b.getPropertiesFromBankFile().getProperty(BiomajConst.keepOldVersionProperty));
 			config.setOfflineDirectory(dataDir+"/"+b.getPropertiesFromBankFile().getProperty(BiomajConst.offlineDirProperty));
-			try {
-			config.setPropertyFile(new File(BiomajInformation.getInstance().getProperty(BiomajInformation.WORKFLOWSDIR)+"/"+dbName+".properties").getAbsolutePath());
-			} catch (BiomajException io) {
-				BiomajLogger.getInstance().log(io);
-				return false;
-			}
+			
+//			config.setPropertyFile(new File(BiomajInformation.getInstance().getProperty(BiomajInformation.WORKFLOWSDIR)+"/"+dbName+".properties").getAbsolutePath());
+			config.setPropertyFile(BankFactory.getBankPath(dbName).getAbsolutePath());
+			
 			
 			config.setProtocol(b.getPropertiesFromBankFile().getProperty(BiomajConst.protocolProperty));
 			config.setReleaseFile(b.getPropertiesFromBankFile().getProperty(BiomajConst.releaseFileProperty));
@@ -1031,13 +1029,17 @@ public class BiomajUtils  {
 				continue;
 			//on verifie qu il existe dabs conf/db_properties
 			String nameBank = xml.getName().split("\\.")[0];
+			/*
 			try {
 			if (!new File(BiomajInformation.getInstance().getProperty(BiomajInformation.WORKFLOWSDIR)+"/"+nameBank+".properties").exists())
 				continue;
 			} catch (BiomajException io) {
 				BiomajLogger.getInstance().log(io);
 				continue;
-			}
+			}*/
+			if (BankFactory.getBankPath(nameBank) == null)
+				continue;
+			
 			Configuration config = new Configuration();
 			if (!BiomajUtils.fillConfig(nameBank, config)) {
 				//System.out.println("Find xml file ["+xml.getAbsolutePath()+"] but no properties file find ["+prop+"]");
@@ -1125,6 +1127,17 @@ public class BiomajUtils  {
 		return arg0.getProject().getProperty(BiomajConst.dbNameProperty);
 	}
 	
+	public static String getNameDirectoryCurrentRelease(Project p) throws BiomajBuildException {
+		File f = new File(p.getProperty(BiomajConst.dataDirProperty)+"/"+p.getProperty(BiomajConst.versionDirProperty)+"/"+BiomajConst.currentLink);
+		
+		if (!f.exists())
+			throw new BiomajBuildException(p,"error.futur.release.not.exist",f.getAbsolutePath(),new Exception());
+		try {
+			return f.getCanonicalPath();
+		} catch (IOException ioe) {
+			throw new BiomajBuildException(p,"io.error",ioe.getMessage(),ioe);
+		}
+	}
 	
 	public static String getNameDirectoryFuturRelease(Project p) throws BiomajBuildException {
 		File f = new File(p.getProperty(BiomajConst.dataDirProperty)+"/"+p.getProperty(BiomajConst.versionDirProperty)+"/"+BiomajConst.futureReleaseLink);
@@ -1258,6 +1271,22 @@ public class BiomajUtils  {
 		}
 	}
 	
+	/**
+	 * Returns child bank names from the project db.source property.
+	 * 
+	 * @param p
+	 * @return
+	 */
+	public static String[] getBankDependencies(Project p) {
+		if (p.getProperty(BiomajConst.dependsListProperty) != null) {
+			String deps = p.getProperty(BiomajConst.dependsListProperty).trim();
+			if (!deps.isEmpty()) {
+				return deps.split(",");
+			}
+		}
+		return new String[0];
+	}
+	
 	public static String getHexString(byte[] buf) {
 		char[] TAB_BYTE_HEX = { '0', '1', '2', '3', '4', '5', '6', '7', '8',
 				'9', 'a', 'b', 'c', 'd', 'e', 'f' };
